
%-------------------------------------------------------------------------
%Input file of VolcFLow used for the simulation of the lava dome
%emplacement. Fig. 8a of the paper : 
%Growth and collapses of the 2018-2019 lava dome of Merapi volcano.
%Kelfoun et al., Bull. Volcanol, 2020
%-------------------------------------------------------------------------

%If you want to use the mat-file (faster)
load('ESM5c_DEM_2019.mat')
[nrow, ncol]=size(z);
dx_horiz = x(2)-x(1); %x-horizontal length of the meshes
dy_horiz = y(1)-y(2); %y-horizontal length of the meshes

% %If you want to use the ASCII DEM
% fid = fopen('ESM5c_DEM_2019.grd'); 
% code = fscanf(fid,'%c',4);
% ncol = fscanf(fid,'%f',1);
% nrow = fscanf(fid,'%f',1);
% xmin = fscanf(fid,'%f',1);
% xmax = fscanf(fid,'%f',1);
% ymin = fscanf(fid,'%f',1);
% ymax = fscanf(fid,'%f',1);
% zmin = fscanf(fid,'%f',1);
% zmax = fscanf(fid,'%f',1);
% zL   = fscanf(fid,'%f', inf);
% z = (reshape(zL, ncol, nrow))';
% z=flipud(z);
% fclose(fid);
% dx_horiz = (xmax-xmin)/(ncol-1);
% dy_horiz = (ymax-ymin)/(nrow-1);
% x = [xmin+dx_horiz/2:dx_horiz:xmin+ncol*dx_horiz-dx_horiz/2];
% y = [ymin+nrow*dy_horiz-dy_horiz/2 : -dy_horiz : ymin+dy_horiz/2];



%Load a grey-scaled image that localises the vent location
hsource = double(imread('ESM5c_vent_location_2019.tif'));
hsource = (255-hsource)/255;

%Load an image to defined, after, the conditions of the simulation
im_conditions = double(imread('ESM5c_bound_cond.tif'));

%Parameters of the simulation
dt     =  100;       %time step of the simulation in seconds
dtmin  =   10;       %minimal value of the time step
dtmax  =  100;       %maximal value of the time step
dtplot = 3600*24;    %time step of plots
tmax = 3600*24*15*100;    %duration of the calculation (in s)

g = 9.79;               %gravity (m/s-2)

tstep_adjust = 1;       %automatic adaptation of the time step
                        %(to be used carefully for very viscous flows but faster)
doubleUpwind = 0;       %Just one upwind scheme is used (and not two)
                        %Stabler for very viscous flow with tstep_adjust = 1
CFLcond = 0.1;          %Courant-Friedrich-Levy condition

%Rheological parameters (viscous flow = just viscosity is defined)
rho         = 2300; %density
delta_int   = 0;
delta_bed   = 0; 
cohesion    = 0;  
coef_u2     = 0;
viscosity   = 2e10; %viscosity

%Source and boundary conditions
Q = 3000; %volume rate of the dome in m3/day
ind_dome = find(hsource > 0.5); %indices of the vent
source = 'ESM5c_source_dome; h(im_conditions>100)=0;'; 
bound_cond = 'h2(:,1)=0; h2(:,ncol)=0; h2(1,:)=0; h2(nrow,:)=0; u_xx(:,1)=0; u_xx(:,ncol-1)=0; u_yy(1,:)=0; u_yy(nrow-1,:)=0;';

%output
representation = 'ESM5c_repr_dome_2019; set(gcf, ''color'', ''w'');';
f_avi = 'test.avi'; %be careful, this file will be deleted
f_data = 'test.dat';%be careful, this file will be deleted
erase_dat = 1;

%internal boudaries 
indCx = []; 
indCy = []; 

%initial thickness
h=z*0; %null thickness, same size as z

%initial velocities
u_xx = z(1:nrow, 1:ncol-1)*0;%-20;
u_xy = z(1:nrow, 1:ncol-1)*0;%+20;
u_yy = z(1:nrow-1, 1:ncol)*0;%+20;
u_yx = z(1:nrow-1, 1:ncol)*0;%-20;


